gnucash utilities
=================

|build-status| |docs|

The GnuCash utilities is a set of utilities built on top of `piecash <https://github.com/sdementen/piecash>`_, a python package to work with GnuCash books.

It will eventually consist of scripts to:
 - import/export gnucash books to various format (csv, QIF, ledger, ...)
 - manipulate gnucash books (duplicate a book, find & replace in transactions/splits, filter transactions)
 - generate reports
 - serve gnucash books on the web (REST)

:Documentation: http://gnucash-utilities.readthedocs.org
:Google group: https://groups.google.com/d/forum/piecash (piecash@googlegroups.com)
:Github: https://github.com/sdementen/gnucash-utilities


.. |build-status| image:: https://travis-ci.org/sdementen/gnucash-utilities.svg?branch=master
    :alt: build status
    :scale: 100%
    :target: https://travis-ci.org/sdementen/gnucash-utilities

.. |docs| image:: https://readthedocs.org/projects/gnucash-utilities/badge/?version=master
    :alt: Documentation Status
    :scale: 100%
    :target: http://gnucash-utilities.readthedocs.org

